@@ -85,8 +85,8 @@ class HttpClient(object):
     def _get(self, rest_command, parameters=None):
         return self._do_request('GET', rest_command, parameters)
 
-    def _post(self, rest_command, file=None):
-        return self._do_request('POST', rest_command, file=file)
+    def _post(self, rest_command, file=None, parameters=None):
+        return self._do_request('POST', rest_command, parameters=parameters, file=file)
 
 
 class ComplexIdMixin(object):
@@ -292,7 +292,9 @@ class LoadMaster(HttpClient):
         # 3 GEO Configuration
         if backup_type not in [1, 2, 3]:
             backup_type = 2
-        response = self._post('/restore?type={}'.format(backup_type), file)
+        params = {"type": backup_type}
+        response = self._post('/restore'.format(backup_type), file=file,
+                              parameters=params)
         if ApiXmlHelper.is_successful(response):
             return ApiXmlHelper.parse_to_dict(response)
         else:
